# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T03:57:17+00:00

from __future__ import annotations

from typing import Any

from pydantic import BaseModel


class Data(BaseModel):
    update_available: bool
    platform: str
    release_date: int
    version: str
    requirements: str
    extra_info: str
    changelog_added: str
    changelog_fixed: str
    label: str
    distro: str
    distro_build: str
    download_url: str


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response
