# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T03:51:24+00:00

from __future__ import annotations

from typing import Any, List, Optional

from pydantic import BaseModel


class Data(BaseModel):
    section_id: int
    section_name: str
    section_type: str
    agent: Optional[str]


class Response(BaseModel):
    result: str
    message: Any
    data: List[Data]


class Model(BaseModel):
    response: Response
