# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T05:06:32+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Net(BaseModel):
    cidr: str
    name: str
    handle: str
    range: str
    description: str
    country: str
    state: str
    city: str
    address: str
    postal_code: str
    emails: List[str]
    created: str
    updated: str


class Data(BaseModel):
    host: str
    nets: List[Net]


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response
