# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T05:07:40+00:00

from __future__ import annotations

from pydantic import BaseModel


class Data(BaseModel):
    server_id: str
    pms_name: str
    pms_version: str
    pms_platform: str
    pms_ip: str
    pms_port: int
    pms_ssl: int
    pms_is_remote: int
    pms_is_cloud: int
    pms_url: str
    pms_url_manual: int
    pms_identifier: str
    pms_plexpass: int
    tautulli_install_type: str
    tautulli_version: str
    tautulli_branch: str
    tautulli_commit: str
    tautulli_platform: str
    tautulli_platform_release: str
    tautulli_platform_version: str
    tautulli_platform_linux_distro: str
    tautulli_platform_device_name: str
    tautulli_python_version: str


class Response(BaseModel):
    result: str
    message: str
    data: Data


class Model(BaseModel):
    response: Response
