# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:22:54+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Datum(BaseModel):
    name: str
    machine_identifier: str
    host: str
    port: str
    version: str


class Response(BaseModel):
    result: str
    message: Any
    data: List[Datum]


class Model(BaseModel):
    response: Response
