# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:54:28+00:00

from __future__ import annotations

from typing import Any

from pydantic import BaseModel


class Data(BaseModel):
    bitrate: int
    video_full_resolution: str
    optimized_version: str
    optimized_version_profile: str
    optimized_version_title: str
    synced_version: str
    synced_version_profile: str
    container: str
    video_codec: str
    video_bitrate: int
    video_width: int
    video_height: int
    video_framerate: str
    video_dynamic_range: str
    aspect_ratio: str
    audio_codec: str
    audio_bitrate: int
    audio_channels: int
    subtitle_codec: str
    stream_bitrate: int
    stream_video_full_resolution: str
    quality_profile: str
    stream_container_decision: str
    stream_container: str
    stream_video_decision: str
    stream_video_codec: str
    stream_video_bitrate: int
    stream_video_width: int
    stream_video_height: int
    stream_video_framerate: str
    stream_video_dynamic_range: str
    stream_audio_decision: str
    stream_audio_codec: str
    stream_audio_bitrate: int
    stream_audio_channels: int
    subtitles: str
    stream_subtitle_decision: str
    stream_subtitle_codec: str
    transcode_hw_decoding: str
    transcode_hw_encoding: str
    video_decision: str
    audio_decision: str
    media_type: str
    title: str
    grandparent_title: str
    original_title: str
    current_session: int
    pre_tautulli: str


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response
