# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:34:08+00:00

from __future__ import annotations

from typing import Any

from pydantic import BaseModel


class Data(BaseModel):
    code: str
    country: str
    region: str
    city: str
    postal_code: str
    timezone: str
    latitude: float
    longitude: float
    continent: Any
    accuracy: Any


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response
