# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:22:02+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Datum(BaseModel):
    httpsRequired: str
    clientIdentifier: str
    label: str
    ip: str
    port: str
    uri: str
    local: str
    value: str
    is_cloud: bool


class Response(BaseModel):
    result: str
    message: Any
    data: List[Datum]


class Model(BaseModel):
    response: Response
