# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:38:24+00:00

from __future__ import annotations

from typing import Any, List, Optional

from pydantic import BaseModel


class Datum(BaseModel):
    video_resolution: str
    audio_channels: str
    container: str
    thumb: str
    media_index: str
    title: str
    bitrate: str
    video_codec: str
    section_type: str
    section_id: int
    added_at: str
    sort_title: str
    file_size: str
    parent_rating_key: str
    audio_codec: str
    year: str
    media_type: str
    parent_media_index: str
    grandparent_rating_key: str
    rating_key: str
    video_framerate: str
    last_played: Optional[int]
    play_count: Optional[int]


class Data(BaseModel):
    recordsFiltered: int
    recordsTotal: int
    data: List[Datum]
    draw: int
    filtered_file_size: int
    total_file_size: int


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response
