# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:50:23+00:00

from __future__ import annotations

from typing import Any

from pydantic import BaseModel, Field


class Field0(BaseModel):
    rating_key: int


class Data(BaseModel):
    field_0: Field0 = Field(..., alias='0')


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response
