# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T05:03:28+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Datum(BaseModel):
    browser: str
    friendly_name: str
    host: str
    ip_address: str
    os: str
    timestamp: int
    user: str
    user_agent: str
    user_group: str
    user_id: int


class Data(BaseModel):
    draw: int
    recordsTotal: int
    recordsFiltered: int
    data: List[Datum]


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response
