# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:56:39+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Datum(BaseModel):
    audio_bitrate: str
    client_id: str
    content_type: str
    device_name: str
    failure: str
    item_complete_count: str
    item_count: str
    item_downloaded_count: str
    item_downloaded_percent_complete: int
    metadata_type: str
    photo_quality: str
    platform: str
    rating_key: str
    root_title: str
    state: str
    sync_id: str
    sync_title: str
    total_size: str
    user: str
    user_id: str
    username: str
    video_bitrate: str
    video_quality: str


class Response(BaseModel):
    result: str
    message: Any
    data: List[Datum]


class Model(BaseModel):
    response: Response
