import os

"""
from typing import Union

from tautulli import models

class TautulliObject:
    def __init__(self, data: dict):
        self._data = data


class Docs(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class Activity(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class DateFormats(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class LibraryNames(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class Newsletters(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class NotifierParameters(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class PMSUpdate(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class ServerIdentity(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class ServerInfo(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class ServerList(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class ServersInfo(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class UserNames(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class Users(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class UpdateCheck(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class CollectionsTable(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class ExportFields(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class GeoIPLookup(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class History(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class HomeStats(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class Library(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class Libraries(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class LibrariesTable(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class LibraryMediaInfo(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class LibraryUserStats(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class LibraryWatchTimeStats(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class Logs(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class Metadata(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class NewRatingKeys(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class NewsletterConfig(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class NewsletterLog(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class NotificationLog(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class NotifierConfig(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class Notifiers(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class OldRatingKeys(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class PlaylistsTable(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class PlexLog(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class RecentlyAdded(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class ServerID(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class Settings(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class StreamData(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class SyncedItems(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class User(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class UserIPs(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class UserLogins(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class UserPlayerStats(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class UserWatchTimeStats(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class UsersTable(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class WHOISLookup(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class RegisteredDevice(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class SearchResults(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class SQLResults(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)
"""