# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T05:02:13+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Datum(BaseModel):
    friendly_name: str
    guid: str
    id: int
    ip_address: str
    last_played: str
    last_seen: int
    first_seen: int
    live: int
    media_index: int
    media_type: str
    originally_available_at: str
    parent_media_index: int
    parent_title: str
    platform: str
    play_count: int
    player: str
    rating_key: int
    thumb: str
    transcode_decision: str
    user_id: int
    year: int


class Data(BaseModel):
    draw: int
    recordsTotal: int
    recordsFiltered: int
    data: List[Datum]


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response
