# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:45:45+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Datum(BaseModel):
    id: int
    timestamp: int
    session_key: int
    rating_key: int
    user_id: int
    user: str
    notifier_id: int
    agent_id: int
    agent_name: str
    notify_action: str
    subject_text: str
    body_text: str
    success: int


class Data(BaseModel):
    recordsFiltered: int
    recordsTotal: int
    data: List[Datum]
    draw: int


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response
