# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:51:38+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Data(BaseModel):
    data: List


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response
