# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:35:02+00:00

from __future__ import annotations

from typing import Any, List, Union

from pydantic import BaseModel


class Datum(BaseModel):
    reference_id: int
    row_id: int
    id: int
    date: int
    started: int
    stopped: int
    duration: int
    paused_counter: int
    user_id: int
    user: str
    friendly_name: str
    platform: str
    product: str
    player: str
    ip_address: str
    live: int
    machine_id: str
    media_type: str
    rating_key: int
    parent_rating_key: Union[int, str]
    grandparent_rating_key: Union[int, str]
    full_title: str
    title: str
    parent_title: str
    grandparent_title: str
    original_title: str
    year: Union[int, str]
    media_index: Union[int, str]
    parent_media_index: Union[int, str]
    thumb: str
    originally_available_at: str
    guid: str
    transcode_decision: str
    percent_complete: int
    watched_status: float
    group_count: int
    group_ids: str
    state: Any
    session_key: Any


class Data(BaseModel):
    recordsFiltered: int
    recordsTotal: int
    data: List[Datum]
    draw: int
    filter_duration: str
    total_duration: str


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response
