# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T01:28:24+00:00

from __future__ import annotations

from typing import Any

from pydantic import BaseModel


class Data(BaseModel):
    add_newsletter_config: str
    add_notifier_config: str
    arnold: str
    backup_config: str
    backup_db: str
    delete_all_library_history: str
    delete_all_user_history: str
    delete_cache: str
    delete_export: str
    delete_history: str
    delete_hosted_images: str
    delete_image_cache: str
    delete_library: str
    delete_login_log: str
    delete_lookup_info: str
    delete_media_info_cache: str
    delete_mobile_device: str
    delete_newsletter: str
    delete_newsletter_log: str
    delete_notification_log: str
    delete_notifier: str
    delete_recently_added: str
    delete_synced_item: str
    delete_temp_sessions: str
    delete_user: str
    docs: str
    docs_md: str
    download_config: str
    download_database: str
    download_export: str
    download_log: str
    download_plex_log: str
    edit_library: str
    edit_user: str
    export_metadata: str
    get_activity: str
    get_apikey: str
    get_collections_table: str
    get_date_formats: str
    get_export_fields: str
    get_exports_table: str
    get_geoip_lookup: str
    get_history: str
    get_home_stats: str
    get_libraries: str
    get_libraries_table: str
    get_library: str
    get_library_media_info: str
    get_library_names: str
    get_library_user_stats: str
    get_library_watch_time_stats: str
    get_logs: str
    get_metadata: str
    get_new_rating_keys: str
    get_newsletter_config: str
    get_newsletter_log: str
    get_newsletters: str
    get_notification_log: str
    get_notifier_config: str
    get_notifier_parameters: str
    get_notifiers: str
    get_old_rating_keys: str
    get_playlists_table: str
    get_plays_by_date: str
    get_plays_by_dayofweek: str
    get_plays_by_hourofday: str
    get_plays_by_source_resolution: str
    get_plays_by_stream_resolution: str
    get_plays_by_stream_type: str
    get_plays_by_top_10_platforms: str
    get_plays_by_top_10_users: str
    get_plays_per_month: str
    get_plex_log: str
    get_pms_token: str
    get_pms_update: str
    get_recently_added: str
    get_server_friendly_name: str
    get_server_id: str
    get_server_identity: str
    get_server_info: str
    get_server_list: str
    get_server_pref: str
    get_servers_info: str
    get_settings: str
    get_stream_data: str
    get_stream_type_by_top_10_platforms: str
    get_stream_type_by_top_10_users: str
    get_synced_items: str
    get_user: str
    get_user_ips: str
    get_user_logins: str
    get_user_names: str
    get_user_player_stats: str
    get_user_watch_time_stats: str
    get_users: str
    get_users_table: str
    get_whois_lookup: str
    import_config: str
    import_database: str
    notify: str
    notify_newsletter: str
    notify_recently_added: str
    pms_image_proxy: str
    refresh_libraries_list: str
    refresh_users_list: str
    register_device: str
    restart: str
    search: str
    server_status: str
    set_mobile_device_config: str
    set_newsletter_config: str
    set_notifier_config: str
    sql: str
    status: str
    terminate_session: str
    undelete_library: str
    undelete_user: str
    update: str
    update_check: str
    update_metadata_details: str


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response
