# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:27:48+00:00

from __future__ import annotations

from typing import Any, List, Optional

from pydantic import BaseModel


class Datum(BaseModel):
    addedAt: str
    art: Any
    childCount: int
    collectionMode: int
    collectionSort: int
    contentRating: Optional[str]
    guid: str
    librarySectionID: str
    librarySectionTitle: str
    maxYear: Optional[int]
    minYear: Optional[int]
    ratingKey: int
    subtype: str
    summary: str
    thumb: str
    title: str
    titleSort: str
    type: str
    updatedAt: str


class Data(BaseModel):
    recordsFiltered: int
    recordsTotal: int
    data: List[Datum]
    draw: int


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response
