# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T05:04:32+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Datum(BaseModel):
    platform_type: str
    player_name: str
    result_id: int
    total_plays: int


class Response(BaseModel):
    result: str
    message: Any
    data: List[Datum]


class Model(BaseModel):
    response: Response
