# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:37:01+00:00

from __future__ import annotations

from typing import Any

from pydantic import BaseModel


class Data(BaseModel):
    row_id: int
    server_id: str
    section_id: int
    section_name: str
    section_type: str
    library_thumb: str
    library_art: str
    count: int
    parent_count: Any
    child_count: Any
    is_active: int
    do_notify: int
    do_notify_created: int
    keep_history: int
    deleted_section: int


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response
