# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:40:08+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Datum(BaseModel):
    time: str
    loglevel: str
    msg: str
    thread: str


class Response(BaseModel):
    result: str
    message: Any
    data: List[Datum]


class Model(BaseModel):
    response: Response
